# Rebuild with  '--with dbus' to enable dbus/Networkmanager support
%global nodbus_support %{?_with_dbus: %nil}%{?!_with_dbus: --disable-dbus-nm}

# Location where helper scripts are located
%define scripts_path /usr/lib/%{name}

Summary:        The NIS daemon which binds NIS clients to an NIS domain
Name:           ypbind
Epoch:          3
Version:        2.7.2
Release:        %mkrel 3
License:        GPLv2
Group:          System/Servers
URL:            https://www.thkukuk.de/nis/nis/ypbind-mt/index.html
Source0:	https://github.com/thkukuk/ypbind-mt/archive/v%{version}.tar.gz#/ypbind-mt-%{version}.tar.gz
Source3:        ypbind.service
Source4:        ypbind-pre-setdomain
Source5:        ypbind-post-waitbind

# Recent systemd doesn't do well with network auth without a local daemon
# https://github.com/systemd/systemd/issues/7074 
Recommends:     nscd

# Fedora patches
Patch1:         ypbind-1.11-gettextdomain.patch

# Not sent to upstream.
Patch2: ypbind-2.5-helpman.patch


%if %{?nodbus_support: 0}%{?!nodbus_support: 1}
BuildRequires:  dbus-devel
BuildRequires:  dbus-glib >= 0.60
BuildRequires:  networkmanager-devel
%endif
# autoconf, automake, systemd-devel needed for patch 3
# gettext-devel also needed for /usr/bin/autopoint
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(systemd)
BuildRequires:  libtirpc-devel
BuildRequires:  libnsl-devel

Requires(post):  rpm-helper
Requires(preun): rpm-helper
Requires:        rpcbind
Requires:        yp-tools

%description
The Network Information Service (NIS) is a system which provides
network information (login names, passwords, home directories, group
information) to all of the machines on a network.  NIS can enable
users to login on any machine on the network, as long as the machine
has the NIS client programs running and the user's password is
recorded in the NIS passwd database.  NIS was formerly known as Sun
Yellow Pages (YP).

This package provides the ypbind daemon.  The ypbind daemon binds NIS
clients to an NIS domain.  Ypbind must be running on any machines
which are running NIS client programs.

Install the ypbind package on any machines which are running NIS client
programs (included in the yp-tools package).  If you need an NIS server,
you'll also need to install the ypserv package to a machine on your
network.

%prep
%setup -q -n ypbind-mt-%{version}
%autopatch -p1
sed -i -e 's/^AM_GNU_GETTEXT_VERSION$/AM_GNU_GETTEXT_VERSION([0.19])/' configure.ac

%build
autoreconf -vfi
%serverbuild
%configure --sbindir=/sbin %{?nodbus_support}
%make_build

%install
%make_install sbindir=/sbin

mkdir -p %{buildroot}%{_sysconfdir}
install -m 644 etc/yp.conf %{buildroot}%{_sysconfdir}/yp.conf
mkdir -p %{buildroot}/var/yp/binding

mkdir -p %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/ypbind.service
mkdir -p %{buildroot}%{scripts_path}
install -m 755 %{SOURCE4} %{buildroot}%{scripts_path}/ypbind-pre-setdomain
install -m 755 %{SOURCE5} %{buildroot}%{scripts_path}/ypbind-post-waitbind

%find_lang %{name}

%post
%_post_service ypbind

%preun
%_preun_service ypbind

%files -f %{name}.lang
%doc README ChangeLog AUTHORS THANKS NEWS
%attr(755, root, root) /sbin/ypbind
%{_mandir}/*/*
%{_unitdir}/*
%{scripts_path}/*
%config(noreplace) %{_sysconfdir}/yp.conf
%dir /var/yp/binding


%changelog
* Mon Feb 08 2021 pterjan <pterjan> 3:2.7.2-3.mga8
+ Revision: 1675070
- Recommend ncsd (mga#28269)

* Sat Dec 12 2020 wally <wally> 3:2.7.2-2.mga8
+ Revision: 1655974
- BR libnsl

* Wed Nov 25 2020 tv <tv> 3:2.7.2-1.mga8
+ Revision: 1649353
- 2.7.2 which builds with tirpc/glibc-2.32

* Sun Mar 22 2020 umeabot <umeabot> 3:1.38-4.mga8
+ Revision: 1558992
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 3.mga7-current
+ Revision: 1302027
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use make_build

* Wed Jan 20 2016 daviddavid <daviddavid> 3:1.38-2.mga6
+ Revision: 925997
- switch to %%configure2_5x to fix build
- fix license

* Sun Jun 21 2015 luigiwalser <luigiwalser> 3:1.38-1.mga6
+ Revision: 837402
- remove patches 0 and 3 (fixed upstream)
- 1.38

* Wed Oct 15 2014 umeabot <umeabot> 3:1.37.2-4.mga5
+ Revision: 742114
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3:1.37.2-3.mga5
+ Revision: 690843
- Mageia 5 Mass Rebuild

* Thu Sep 04 2014 colin <colin> 3:1.37.2-2.mga5
+ Revision: 672040
- Rebuild for new systemd

* Sat Aug 16 2014 luigiwalser <luigiwalser> 3:1.37.2-1.mga5
+ Revision: 664083
- 1.37.2
- rediff patch 0
- remove nistimeout patch (integrated into helpman patch)
- update helpman patch from fedora
- add patch from fedora to link with systemd.so

* Sat Oct 19 2013 umeabot <umeabot> 3:1.37.1-4.mga4
+ Revision: 533091
- Mageia 4 Mass Rebuild

* Sun Aug 25 2013 luigiwalser <luigiwalser> 3:1.37.1-3.mga4
+ Revision: 471520
- sync with fedora:
  - enable PrivateTmp feature
  - update helpman and nistimeout patches (systemd documentation)
  - clean up ypbind-pre-setdomain helper script

* Sun Aug 25 2013 luigiwalser <luigiwalser> 3:1.37.1-2.mga4
+ Revision: 471516
- try to fix newest automake error by specifying gettext version
- BR gettext-devel for autopoint
- use autoreconf -fi to try to fix build error

* Thu May 09 2013 luigiwalser <luigiwalser> 3:1.37.1-1.mga4
+ Revision: 412784
- add patch from fedora to sync help and man pages
- 1.37.1
- remove upstreamed patches

* Sun Mar 10 2013 luigiwalser <luigiwalser> 3:1.36-3.mga3
+ Revision: 402042
- Sync more changes from fedora:
  - Enhance ypbind(8) with info about NISTIMEOUT
  - Add suggestion about extending NISTIMEOUT if ypbind timeouts
  - Use sdnotify to inform systemd that daemon is ready
  - Add After: NetworkManager-wait-online.service (rhbz#846767)
  - Check presence of ypbind in /etc/rpc (rhbz#888778)
  - Make re-bind interval a tune-able option

* Mon Jan 14 2013 umeabot <umeabot> 3:1.36-2.mga3
+ Revision: 387612
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jul 29 2012 luigiwalser <luigiwalser> 3:1.36-1.mga3
+ Revision: 275828
- 1.36 (partial sync with fedora)

* Sat Jun 30 2012 nanardon <nanardon> 3:1.33-3.mga3
+ Revision: 265461
- fix rpcbind path

* Sat Jun 30 2012 nanardon <nanardon> 3:1.33-2.mga3
+ Revision: 265416
- switch to systemd (from Fedora works)
+ luigiwalser <luigiwalser>
- fix source URL

* Tue Sep 06 2011 tv <tv> 3:1.33-1.mga2
+ Revision: 139499
- fix missing LSB keywords
- new release
- use bz2 sources

* Fri Apr 15 2011 nanardon <nanardon> 3:1.32-2.mga1
+ Revision: 85862
- 1.32

* Sun Jan 16 2011 nanardon <nanardon> 3:1.29.91-4.mga1
+ Revision: 19984
- cleanup useless white line
- imported package ypbind

